﻿using Syncfusion.UI.Xaml.Controls.Input;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Cells;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel.DataAnnotations;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

using Syncfusion.UI.Xaml.Grid.Helpers;
using Syncfusion.Data;
using System.Reflection;
using Syncfusion.UI.Xaml.ScrollAxis;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace MasterDetailsViewSingleLevel
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        private void GetDetailsViewDataGrid_Click(object sender, RoutedEventArgs e)
        {

            //parent DataGrid row index
            int parentRowIndex = 9;

            RecordEntry record = null;
            var recordIndex = this.dataGrid.ResolveToRecordIndex(parentRowIndex);
            if (this.dataGrid.View != null && this.dataGrid.View.GroupDescriptions.Any())
                record = (this.dataGrid.View.TopLevelGroup.DisplayElements[recordIndex] is RecordEntry) ? (this.dataGrid.View.TopLevelGroup.DisplayElements[recordIndex] as RecordEntry) : null;
            else
                record = this.dataGrid.View.Records[recordIndex];
            if (record == null)
                return;

            // Get the DetailsViewManager using Reflection
            var propertyInfo = dataGrid.GetType().GetField("DetailsViewManager", System.Reflection.BindingFlags.Instance | System.Reflection.BindingFlags.NonPublic);
            DetailsViewManager detailsViewManager = propertyInfo.GetValue(dataGrid) as DetailsViewManager;

            // Expand DetailsView at specified record index
            if (!record.IsExpanded) this.dataGrid.ExpandDetailsViewAt(this.dataGrid.ResolveToRecordIndex(parentRowIndex));

            //   find DetailsViewDataRow index based on relational column
            int index = 0;
            foreach (var def in this.dataGrid.DetailsViewDefinition)
            {
                if (def.RelationalColumn == "ProductDetails")
                {
                    index = this.dataGrid.DetailsViewDefinition.IndexOf(def);
                    index = parentRowIndex + index + 1;
                }
            }


            var rowcolumnIndex = new RowColumnIndex(index, 1);
            // if the DetailsViewDataGrid is already expanded, bring that into view
            dataGrid.ScrollInView(rowcolumnIndex);
            //Get the DetailsViewDataGrid by passing the corresponding row index and relation name
            var detailsViewDataGrid = this.dataGrid.GetDetailsViewGrid(this.dataGrid.ResolveToRecordIndex(parentRowIndex), "ProductDetails");

            //if the DetailsViewDataGrid is not already expanded, call BringIntoView method
            if (detailsViewDataGrid == null)
            {
                detailsViewManager.BringIntoView(index);
            }
        }
    }

    public class OrderInfo
    {
        int orderID;
        string customerId;
        string country;
        string customerName;
        string shippingCity;
        List<ProductInfo> productDetails;

        public int OrderID
        {
            get { return orderID; }
            set { orderID = value; }
        }

        public string CustomerID
        {
            get { return customerId; }
            set { customerId = value; }
        }

        public string CustomerName
        {
            get { return customerName; }
            set { customerName = value; }
        }

        public string Country
        {
            get { return country; }
            set { country = value; }
        }

        public string ShipCity
        {
            get { return shippingCity; }
            set { shippingCity = value; }
        }

        public List<ProductInfo> ProductDetails
        {
            get { return productDetails; }
            set { productDetails = value; }
        }


        public OrderInfo(int orderId, string customerName, string country, string customerId, string shipCity, List<ProductInfo> productdetails)
        {
            this.OrderID = orderId;
             this.CustomerName = customerName;
            this.Country = country;
            this.CustomerID = customerId;
            this.ShipCity = shipCity;
            this.ProductDetails = productdetails;
        }
    }
    public class ProductInfo
    {
        int orderId;
        string productName;
        DateTime dateOfMonth;

        public int OrderID
        {
            get { return orderId; }
            set { orderId = value; }
        }

        [Required()]
        public string ProductName
        {
            get { return productName; }
            set { productName = value; }
        }

        public DateTime DateOfMonth
        {
            get { return dateOfMonth; }
            set { dateOfMonth = value; }
        }
    }
    public class OrderInfoRepositiory
    {
        ObservableCollection<OrderInfo> orders;
        public ObservableCollection<OrderInfo> Orders
        {
            get { return orders; }
            set { orders = value; }
        }

        public OrderInfoRepositiory()
        {
            orders = new ObservableCollection<OrderInfo>();
            this.GenerateProducts();
            Orders = GenerateOrders();
        }

        public ObservableCollection<OrderInfo> GenerateOrders()
        {
            orders.Add(new OrderInfo(1001, "Maria Anders", "Germany", "ALFKI", "Berlin", getorder(1001)));
            orders.Add(new OrderInfo(1002, "Ana Trujilo", "Mexico", "ANATR", "México D.F.", getorder(1002)));
            orders.Add(new OrderInfo(1003, "Antonio Moreno", "Mexico", "ANTON", "México D.F.", getorder(1003)));
            orders.Add(new OrderInfo(1004, "Thomas Hardy", "UK", "AROUT", "London", getorder(1004)));
            orders.Add(new OrderInfo(1005, "Christina Berglund", "Sweden", "BERGS", "Luleå", getorder(1005)));
            orders.Add(new OrderInfo(1006, "Hanna Moos", "Germany", "BLAUS", "Mannheim", getorder(1006)));
            orders.Add(new OrderInfo(1007, "Frédérique Citeaux", "France", "BLONP", "Strasbourg", getorder(1007)));
            orders.Add(new OrderInfo(1008, "Martin Sommer", "Spain", "BOLID", "Madrid", getorder(1008)));
            orders.Add(new OrderInfo(1009, "Laurence Lebihan", "France", "BONAP", "Marseille", null));
            orders.Add(new OrderInfo(1010, "Elizabeth Lincoln", "Canada", "BOTTM", "Tsawassen", null));
            return orders;
        }

        List<ProductInfo> products = new List<ProductInfo>();

        public void GenerateProducts()
        {
            products.Add(new ProductInfo() { OrderID = 1001, ProductName = "", DateOfMonth = new DateTime(2015, 5, 27) });
            products.Add(new ProductInfo() { OrderID = 1001, ProductName = "Bike2", DateOfMonth = new DateTime(2015, 5, 20) });
            products.Add(new ProductInfo() { OrderID = 1001, ProductName = "Bike2", DateOfMonth = new DateTime(2015, 5, 27) });
            products.Add(new ProductInfo() { OrderID = 1002, ProductName = "Bike5", DateOfMonth = new DateTime(2014, 5, 7) });
            products.Add(new ProductInfo() { OrderID = 1002, ProductName = "Bike1", DateOfMonth = new DateTime(2012, 5, 20) });
            products.Add(new ProductInfo() { OrderID = 1002, ProductName = "Bike3", DateOfMonth = new DateTime(2015, 5, 27) });
            products.Add(new ProductInfo() { OrderID = 1003, ProductName = "Bike2", DateOfMonth = new DateTime(2015, 5, 27) });
            products.Add(new ProductInfo() { OrderID = 1003, ProductName = "Bike1" });
            products.Add(new ProductInfo() { OrderID = 1004, ProductName = "Bike2" });
            products.Add(new ProductInfo() { OrderID = 1004, ProductName = "Bike2" });
            products.Add(new ProductInfo() { OrderID = 1005, ProductName = "Bike3" });
            products.Add(new ProductInfo() { OrderID = 1005, ProductName = "Bike4" });
            products.Add(new ProductInfo() { OrderID = 1005, ProductName = "Bike5" });
            products.Add(new ProductInfo() { OrderID = 1006, ProductName = "Bike1" });
            products.Add(new ProductInfo() { OrderID = 1006, ProductName = "Bike2" });
            products.Add(new ProductInfo() { OrderID = 1007, ProductName = "Bike1" });
            products.Add(new ProductInfo() { OrderID = 1008, ProductName = "Bike4" });
            products.Add(new ProductInfo() { OrderID = 1008, ProductName = "Bike6" });
            products.Add(new ProductInfo() { OrderID = 1008, ProductName = "Bike7" });
        }

        public List<ProductInfo> getorder(int i)
        {
            List<ProductInfo> product = new List<ProductInfo>();
            foreach (var or in products)
                if (or.OrderID == i)
                    product.Add(or);
            return product;
        }
    }

}
